@@ -548,4 +548,7 @@ class Structure:
         structure.create_alembic_folder()
         structure.create_alembic_files()
 
+        # .env
+        structure.create_dotenv()
+
         return structure
