@@ -604,7 +604,7 @@ app = get_application()
 def main():
     import uvicorn
 
-    uvicorn.run("adapty_listener.main:app", reload=True)
+    uvicorn.run("{project_folder}.main:app", reload=True)
 
 """
 
